==> mesh-3.0.1-sources.jar: no/nordicsemi/android/mesh/MeshProvisioningStatusCallbacks.java <==
/*
 * Copyright (c) 2018, Nordic Semiconductor
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this
 * software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package no.nordicsemi.android.mesh;

import no.nordicsemi.android.mesh.provisionerstates.ProvisioningState;
import no.nordicsemi.android.mesh.provisionerstates.UnprovisionedMeshNode;
import no.nordicsemi.android.mesh.transport.ProvisionedMeshNode;

/**
 * Callbacks to notify status during the provisioning process
 */
public interface MeshProvisioningStatusCallbacks {

    /**
     * Invoked when the provisioning state changed.
     *
     * @param meshNode {@link UnprovisionedMeshNode} unprovisioned node.
     * @param state    {@link ProvisioningState.State} each provisioning state.
     * @param data     data that was sent or received during each provisioning state.
     */
    void onProvisioningStateChanged(final UnprovisionedMeshNode meshNode, final ProvisioningState.States state, final byte[] data);

    /**
     * Invoked when the provisioning state changed.
     *
     * @param meshNode {@link UnprovisionedMeshNode} unprovisioned node.
     * @param state    {@link ProvisioningState.State} each provisioning state.
     * @param data     data that was sent or received during each provisioning state.
     */
    void onProvisioningFailed(final UnprovisionedMeshNode meshNode, final ProvisioningState.States state, final byte[] data);

    /**
     * Invoked when the provisioning state changed.
     *
     * @param meshNode {@link ProvisionedMeshNode} provisioned mesh node.
     * @param state    {@link ProvisioningState.State} each provisioning state.
     * @param data     data that was sent or received during each provisioning state.
     */
    void onProvisioningCompleted(final ProvisionedMeshNode meshNode, final ProvisioningState.States state, final byte[] data);

}

==> mesh-3.3.4-sources.jar: no/nordicsemi/android/mesh/MeshProvisioningStatusCallbacks.java <==
/*
 * Copyright (c) 2018, Nordic Semiconductor
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this
 * software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package no.nordicsemi.android.mesh;

import androidx.annotation.Nullable;
import no.nordicsemi.android.mesh.provisionerstates.ProvisioningState;
import no.nordicsemi.android.mesh.provisionerstates.UnprovisionedMeshNode;
import no.nordicsemi.android.mesh.transport.ProvisionedMeshNode;

/**
 * Callbacks to notify status during the provisioning process
 */
public interface MeshProvisioningStatusCallbacks {

    /**
     * Invoked when the provisioning state changed.
     *
     * @param meshNode {@link UnprovisionedMeshNode} unprovisioned node.
     * @param state    {@link ProvisioningState.State} each provisioning state.
     * @param data     data that was sent or received during each provisioning state.
     */
    void onProvisioningStateChanged(final UnprovisionedMeshNode meshNode, final ProvisioningState.States state, @Nullable final byte[] data);

    /**
     * Invoked when the provisioning state changed.
     *
     * @param meshNode {@link UnprovisionedMeshNode} unprovisioned node.
     * @param state    {@link ProvisioningState.State} each provisioning state.
     * @param data     data that was sent or received during each provisioning state.
     */
    void onProvisioningFailed(final UnprovisionedMeshNode meshNode, final ProvisioningState.States state, final byte[] data);

    /**
     * Invoked when the provisioning state changed.
     *
     * @param meshNode {@link ProvisionedMeshNode} provisioned mesh node.
     * @param state    {@link ProvisioningState.State} each provisioning state.
     * @param data     data that was sent or received during each provisioning state.
     */
    void onProvisioningCompleted(final ProvisionedMeshNode meshNode, final ProvisioningState.States state, final byte[] data);

}
